#!/bin/sh

if [ -e .ipkg-work ]; then
    /bin/rm -rf .ipkg-work
fi

mkdir .ipkg-work
cd .ipkg-work

# create control file
mkdir CONTROL
cat >CONTROL/control <<EOF
Package: xqt-server
Priority: optional
Section: Qtopia
Maintainer: Takuya Murakami <tmurakam@mtd.biglobe.ne.jp>
Architecture: arm
Version: 0.0.2
Depends:
Description: X/Qt Server 
 XFree86 server port over Qtopia.
License: GPL
EOF

mkdir -p opt/QtPalmtop/apps/Applications
mkdir -p opt/QtPalmtop/bin
mkdir -p opt/QtPalmtop/pics
mkdir -p opt/QtPalmtop/i18n/ja
mkdir -p opt/QtPalmtop/help/html
mkdir -p opt/QtPalmtop/help/ja/html

cp ../programs/Xserver/Xqt opt/QtPalmtop/bin
cp ../programs/Xserver/hw/xqt/Xqt.desktop opt/QtPalmtop/apps/Applications
cp ../programs/Xserver/hw/xqt/Xqt.png opt/QtPalmtop/pics
iconv --to-code=utf8 ../Xqt.html > opt/QtPalmtop/help/html/Xqt.html

cd ..
ipkg-build .ipkg-work

